pub struct CancelToken(/* private fields */);runtime only.Expand description
A token that can be used to cancel multiple operations at once.
When CancelToken::cancel is called, all operations that have been
registered with this token will be cancelled.
It is also possible to use CancelToken::wait to wait until the token is
cancelled, which can be useful for implementing timeouts or other
cancellation-based logic.
To associate a future with this cancel token, use the with_cancel
combinator from the FutureExt trait, which requires nightly feature
future-combinator.
Implementations
Sourceimpl CancelToken
impl CancelToken
Sourcepub fn new() -> CancelToken
pub fn new() -> CancelToken
Create a new cancel token.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if this token has been cancelled.
Sourcepub fn register<T>(&self, key: &Key<T>)where
T: OpCode,
pub fn register<T>(&self, key: &Key<T>)where
T: OpCode,
Register an operation with this token.
If the token has already been cancelled, the operation will be cancelled
immediately. Usually this method should not be used directly, but rather
through the with_cancel combinator, which requires nightly feature
future-combinator.
Multiple registrations of the same key does nothing, and the key will only be cancelled once.
Sourcepub async fn current() -> Option<CancelToken>
pub async fn current() -> Option<CancelToken>
Try to get the current cancel token associated with the future.
This is done by checking if the current context has a cancel token
associated with it. This will only work with nightly feature
future-combinator turned on; otherwise, None is always returned.